@@ -89,13 +89,13 @@ private:
      * @return False if user cancel action. True does not mean, that the user has saved the game, but
      * has taken a decision to save it or not and wants to go on.
      */
-    bool askSaveGame();
+    bool askSaveGame(const QString &dontAskAgainName);
 
     /**
      * @brief Test if game has changed and ask user for saving the game.
      * @return False if user cancels action, else true. 
      */
-    bool testForGameChangeSave();
+    bool testForGameChangeSave(const QString &dontAskAgainName);
 
     bool m_gameChanged = false;
     bool m_bLastRandomSetting;
